pub struct ClientConnection(/* private fields */);Expand description
A connection to a separate client process over the ACP protocol.
Implementations
Sourceimpl ClientConnection
impl ClientConnection
pub fn connect_to_client<H: 'static + Agent>( handler: H, outgoing_bytes: impl Unpin + AsyncWrite, incoming_bytes: impl Unpin + AsyncRead, spawn: impl Fn(LocalBoxFuture<'static, ()>) + 'static, ) -> (Self, impl Future<Output = Result<(), Error>>)
pub fn request<R: ClientRequest>( &self, params: R, ) -> impl use<R> + Future<Output = Result<R::Response, Error>>
Sourcepub fn request_any(
&self,
method: &'static str,
params: AnyClientRequest,
) -> impl Future<Output = Result<AnyClientResult, Error>>
pub fn request_any( &self, method: &'static str, params: AnyClientRequest, ) -> impl Future<Output = Result<AnyClientResult, Error>>
Send an untyped request to the client and wait for a response.